[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Odin
Super Fast and super cheap object detection at massive scale in less than 10 lines of code!

# Appreciation
* Lucidrains
* Agorians



# Install

# Usage

# Architecture

# Todo


# License
MIT

# Citations

